#!/bin/sh
##################################################################################

#                                                                            
#                             NOTICE                                     
#                                                                            
#                    COPYRIGHT 2009-2024 Marvell                      
#                       ALL RIGHTS RESERVED                              
#                                                                            
# Name: remove_conf_file.sh
# Description:
# 	Delete library  conf file. 
#
#
##################################################################################
                                                                            

# Find what platform that we are running on
OS_REL=$(cat /etc/*release 2>/dev/null | grep -w "ID" | sed 's/"//g' | cut -f2 -d"=")
PLATFORM=$(uname -m | sed "s/i.86/i386/")
SUP_PLATFORM=${PLATFORM}
KERNEL=`uname -r | awk '{print substr($1,1,3)}'`
LIBDIR="/usr/lib64"
TMPDIR="/tmp"
CURDIR=`pwd`
KERNELSRC="2.6"
LIBPATH="x86_64"
LIBRARY_PATH="${CURDIR}"

#set -x 

#Check for ubuntu
if [ "$OS_REL" = "ubuntu" ]; then
    if [ "$PLATFORM" = "ppc64le" ]; then
        LIBPATH="powerpc64le-linux-gnu"
        if [ -d /lib/powerpc64le-linux-gnu ]; then
           LIBDIR="/lib/powerpc64le-linux-gnu"
           LIBPATH="powerpc64le-linux-gnu"
        else
           LIBDIR="/usr/lib64"
        fi
    elif [ "$PLATFORM" = "ppc64" ]; then
        LIBPATH="ppc64-linux-gnu"
        if [ -d /lib/ppc64le-linux-gnu ]; then
           LIBDIR="/lib/ppc64-linux-gnu"
        else
           LIBDIR="/usr/lib64"
        fi
    elif [ "$PLATFORM" = "aarch64" ]; then
        LIBPATH="aarch64-linux-gnu"
        if [ -d /lib/aarch64-linux-gnu ]; then
           LIBDIR="/lib/aarch64-linux-gnu"
        elif [ -d /usr/lib/aarch64-linux-gnu ]; then
           LIBDIR="/usr/lib/aarch64-linux-gnu"
        elif [ -d /usr/lib64 ]; then
           LIBDIR="/usr/lib64"
        else
           LIBDIR="/usr/lib"
        fi
    elif [ "$PLATFORM" = "x86_64" ]; then
        LIBPATH="x86_64-linux-gnu"
        if [ -d /usr/lib/x86_64-linux-gnu ]; then
           LIBDIR="/usr/lib/x86_64-linux-gnu"
        elif [ -d /usr/lib64 ]; then
           LIBDIR="/usr/lib64"
        else 
           LIBDIR="/usr/lib"
        fi
    else 
        LIBPATH="x86_64"
        LIBDIR="/usr/lib64"
    fi
elif [ "$OS_REL" = "redhat" -o "$OS_REL" = "sles" ]; then
     # Check for Red Hat / SuSE
     if [ "$PLATFORM" = "aarch64" ]; then
        LIBPATH="aarch64-linux-gnu"
        if [ -d /usr/lib/aarch64-linux-gnu ]; then
            LIBDIR="/usr/lib/aarch64-linux-gnu"
        elif [ -d /usr/lib64 ]; then
            LIBDIR="/usr/lib64"
        else
            LIBDIR="/usr/lib"
        fi
     elif [ "$PLATFORM" = "ppc64le" ]; then
        LIBPATH="powerpc64le-linux-gnu"
        if [ -d /lib/powerpc64le-linux-gnu ]; then
           LIBDIR="/lib/powerpc64le-linux-gnu"
        else
           LIBDIR="/usr/lib64"
        fi
     elif [ "$PLATFORM" = "ppc64" ]; then
        LIBPATH="pc64-linux-gnu"
        if [ -d /lib/ppc64-linux-gnu ]; then
           LIBDIR="/lib/pc64-linux-gnu"
        else
           LIBDIR="/usr/lib64"
        fi
     elif [ $PLATFORM == "x86_64" ]; then
        LIBPATH="x86_64"
        if [ -d /usr/lib64 ]; then
           LIBDIR="/usr/lib64"
        else
           # Debian
           LIBDIR="/usr/lib"
      fi
    else
        LIBPATH="x86_64"
        LIBDIR="/usr/lib"
    fi
else
     # Check for debian kylyn centos xenenterprise (x86_64/arm64)
     PLATFORM=$(uname -m | sed "s/i.86/i386/")
     if [ "$PLATFORM" = "aarch64" ]; then
        if [ "$OS_REL" = "kylin" ]; then
           LIBPATH="x86_64"
           LIBDIR="/usr/lib64"
        else
           if [ -d /usr/lib/aarch64-linux-gnu ]; then
              LIBPATH="aarch64-linux-gnu"
              LIBDIR="/usr/lib/aarch64-linux-gnu"
           elif [ -d /usr/lib64 ]; then
              LIBPATH="x86_64"
              LIBDIR="/usr/lib64"
           else
              LIBDIR="/usr/lib"
           fi
        fi
     elif [ "$PLATFORM" = "ppc64le" ]; then
        if [ -d /lib/powerpc64le-linux-gnu ]; then
           LIBDIR="/lib/powerpc64le-linux-gnu"
        else
           LIBPATH="x86_64"
           LIBDIR="/usr/lib64"
        fi
     elif [ "$PLATFORM" = "ppc64" ]; then
        if [ -d /lib/ppc64-linux-gnu ]; then
           LIBDIR="/lib/pc64-linux-gnu"
        else
           LIBPATH="x86_64"
           LIBDIR="/usr/lib64"
        fi
     elif [ $PLATFORM == "x86_64" ]; then
        if [ "$OS_REL" = "debian" ]; then
           LIBPATH="x86_64-linux-gnu"
           LIBDIR="/usr/lib/x86_64-linux-gnu"
        else
           if [ -d /usr/lib64 ]; then
              LIBPATH="x86_64"
              LIBDIR="/usr/lib64"
           elif [ -d /usr/lib/x86_64-linux-gnu ]; then
              ls -l /usr/lib/x86_64-linux-gnu/*.so 2>/dev/null
              if [ $? -eq 0 ]; then
                 LIBPATH="x86_64-linux-gnu"
                 LIBDIR="/usr/lib/x86_64-linux-gnu"
              else
                 LIBPATH="x86_64"
                 LIBDIR="/usr/lib64"
              fi
           fi
        fi
     else
        LIBPATH="x86_64"
        LIBDIR="/usr/lib64"
    fi
fi


BACKUP_DATE=`date +%m%d%y-%H_%M_%S`
LOGFILE=${TMPDIR}/remove_lib_conf_${BACKUP_DATE}.log

####################################################
#                                                  #
# remove_library_conf_file                         #
# Adds the application shared library files to the #
# system's library path                            #
# Paramters:                                       #
####################################################

remove_library_conf_file()
{
	LIBRARY_PATH="/tmp/payload"

        if [ -d /etc/ld.so.conf.d ]; then
       		if [ -f /etc/ld.so.conf.d/02-qfu-${LIBPATH}.conf ]; then
 			LIBRARY_PATH=`grep libqlsdm.so /etc/hba.conf | awk ' { print $2 } ' | sed -e 's/libqlsdm.so//' | sed 's/\/*$//g'`
			rm -f /etc/ld.so.conf.d/02-qfu-${LIBPATH}.conf 2>/dev/null
                fi
        fi

}


ETC_HBA_CONF=/etc/hba.conf

ETC_NEW_HBA_CONF="${TMPDIR}/new_hba.conf"

LOCAL_HBA_CONF="${CURDIR}/hba.conf"

####################################################
#                                                  #
# update_hba_conf_file                         i   #
# Adds the application shared library files to the #
# system's library path                            #
# Paramters:                                       #
####################################################
update_hba_conf_file()
{
        BKP=0
        LIBQLSDM_PATH=""
        if [ -s $ETC_HBA_CONF ]; then
                 BKP=1
        else
                if [ -f ${CURDIR}/hba.conf ]; then
                        cp -f ${CURDIR}/hba.conf /etc
                else
                        echo "# Auto generated hba.conf file" > ${CURDIR}/hba.conf
                        echo "#debuglevel 3" >> ${CURDIR}/hba.conf
                        cp -f ${CURDIR}/hba.conf /etc
                fi
        fi

        grep "qla2xxxqfu" $ETC_HBA_CONF | grep libqlsdm.so 2>&1 > /dev/null
        if [ $? -eq 0 ]; then
                if [ "${BKP}" -eq 1 ]; then
                        cp -f ${ETC_HBA_CONF} ${ETC_HBA_CONF}.${BACKUP_DATE}.0.bak
                fi
                LIBQLSDM_PATH=`echo "${LIBRARY_PATH}/libqlsdm.so"`
                sed -i '/payload/d' $ETC_HBA_CONF 2>&1 > /dev/null
        fi

        if [ -f ${LIBDIR}/libqlsdm.so ]; then
        	if [ -r $ETC_HBA_CONF ] && [ -w $ETC_HBA_CONF ]; then
                	cp -f $ETC_HBA_CONF $ETC_NEW_HBA_CONF
                	if [ "$SUP_PLATFORM" = "x86_64" ]; then
                        	grep "qla2xxxqfu" $ETC_NEW_HBA_CONF 2>&1 > /dev/null
                        	if [ $? -ne 0 ]; then
                                	echo "qla2xxxqfu ${LIBDIR}/libqlsdm.so" >> $ETC_NEW_HBA_CONF
                                	sed -e '/^[[:space:]]*qla2xxxqfu*/d' $ETC_NEW_HBA_CONF 2>&1 > /dev/null
                        	fi
                	else
                        	grep "qla2xxxqfu" $ETC_NEW_HBA_CONF 2>&1 > /dev/null
                        	if [ $? -ne 0 ]; then
                                	echo "qla2xxxqfu ${LIBDIR}/libqlsdm.so" >> $ETC_NEW_HBA_CONF
                                	sed -e '/^[[:space:]]*qla2xxxqfu*/d' $ETC_NEW_HBA_CONF 2>&1 > /dev/null
                        	fi
                	fi

                	#now move the new hba.conf and backup original ones
                	if [ "${BKP}" -eq 1 ]; then
                        	mv -f --suffix=.${BACKUP_DATE}.bak --backup=existing $ETC_NEW_HBA_CONF $ETC_HBA_CONF
                	else
                        	mv -f $ETC_NEW_HBA_CONF $ETC_HBA_CONF
                	fi
        	else
                	echo "Cannot update /etc/hba.conf. Permission denied."
                	exit
        	fi
        else
              	if [ "$LIBDIR" = "/usr/lib64" ]; then
                	sed -i '/lib64/d' $ETC_HBA_CONF 2>&1 > /dev/null
                elif [ "$LIBDIR" = "/lib/aarch64-linux-gnu" ]; then
                	sed -i '/aarch64-linux-gnu/d' $ETC_HBA_CONF 2>&1 > /dev/null
                elif [ "$LIBDIR" = "/lib/powerpc64le-linux-gnu/" ]; then
                	sed -i '/powerpc64le-linux-gnu/d' $ETC_HBA_CONF 2>&1 > /dev/null
                fi
			
	fi
}

# Handle different platform

echo "Removing library conf file..."  > ${LOGFILE}
echo "OS: $OS_REL"  >> ${LOGFILE}
echo "Architecture: $PLATFORM"  >> ${LOGFILE}
echo "Kernel: $KERNEL"  >> ${LOGFILE}
echo "Library Directory: $LIBDIR"  >> ${LOGFILE}


remove_library_conf_file
update_hba_conf_file

# update linker cache for new lib
ldconfig > /dev/null 2>&1 >> ${LOGFILE}


echo "Done." >> ${LOGFILE}
